@@ -1,13 +1,12 @@
 import time
 import asyncio
 
-import requests
 import aiohttp
+import requests
 
 from python_rucaptcha.config import app_key
-from python_rucaptcha.errors import RuCaptchaError
-from python_rucaptcha.result_handler import get_sync_result, get_async_result
 from python_rucaptcha.decorators import api_key_check, service_check
+from python_rucaptcha.result_handler import get_sync_result, get_async_result
 
 
 class KeyCaptcha:
@@ -17,7 +16,7 @@ class KeyCaptcha:
         service_type: str = "2captcha",
         sleep_time: int = 15,
         pingback: str = None,
-        **kwargs
+        **kwargs,
     ):
         """
 
@@ -71,11 +70,7 @@ class KeyCaptcha:
                     captchaSolve - решение капчи,
                     taskId - находится Id задачи на решение капчи, можно использовать при жалобах и прочем,
                     error - False - если всё хорошо, True - если есть ошибка,
-                    errorBody - полная информация об ошибке:
-                        {
-                            text - Развернётое пояснение ошибки
-                            id - уникальный номер ошибка в ЭТОЙ бибилотеке
-                        }
+                    errorBody - название ошибки
         """
         # result, url_request, url_response - задаются в декораторе `service_check`, после проверки переданного названия
 
@@ -104,12 +99,7 @@ class KeyCaptcha:
 
         # если вернулся ответ с ошибкой то записываем её и возвращаем результат
         if captcha_id["status"] == 0:
-            self.result.update(
-                {
-                    "error": True,
-                    "errorBody": RuCaptchaError().errors(captcha_id["request"]),
-                }
-            )
+            self.result.update({"error": True, "errorBody": captcha_id["request"]})
             return self.result
 
         # иначе берём ключ отправленной на решение капчи и ждём решения
@@ -146,7 +136,7 @@ class aioKeyCaptcha:
         service_type: str = "2captcha",
         sleep_time: int = 15,
         pingback: str = None,
-        **kwargs
+        **kwargs,
     ):
         """
         :param rucaptcha_key: АПИ ключ капчи из кабинета пользователя
@@ -212,11 +202,7 @@ class aioKeyCaptcha:
                     captchaSolve - решение капчи,
                     taskId - находится Id задачи на решение капчи, можно использовать при жалобах и прочем,
                     error - False - если всё хорошо, True - если есть ошибка,
-                    errorBody - полная информация об ошибке:
-                        {
-                            text - Развернётое пояснение ошибки
-                            id - уникальный номер ошибка в ЭТОЙ бибилотеке
-                        }
+                    errorBody - название ошибки
         """
         # result, url_request, url_response - задаются в декораторе `service_check`, после проверки переданного названия
 
@@ -242,19 +228,12 @@ class aioKeyCaptcha:
 
         # получаем ID капчи
         async with aiohttp.ClientSession() as session:
-            async with session.post(
-                url=self.url_request, data=self.post_payload
-            ) as resp:
+            async with session.post(url=self.url_request, data=self.post_payload) as resp:
                 captcha_id = await resp.json()
 
         # если вернулся ответ с ошибкой то записываем её и возвращаем результат
         if captcha_id["status"] == 0:
-            self.result.update(
-                {
-                    "error": True,
-                    "errorBody": RuCaptchaError().errors(captcha_id["request"]),
-                }
-            )
+            self.result.update({"error": True, "errorBody": captcha_id["request"]})
             return self.result
 
         else:
